@@ -1,4 +1,4 @@
-_allcolor = \
+__color__ = \
 [
         "\033[0m",
         "\033[30m", "\033[90m",
@@ -16,14 +16,23 @@ _allcolor = \
         "\033[2;34m", "\033[2;94m",
         "\033[2;35m", "\033[2;95m",
         "\033[2;36m", "\033[2;96m",
-        "\033[2;37m", "\033[2;97m",
+        "\033[2;37m", "\033[2;97m"
 ]
-def _AddColorToning():
-    for R in range(256):
-        for G in range(256):
-            for B in range(256):
-                _allcolor.append(f"\033[38;2;{R};{G};{B}m")
-class __black:
+
+
+def __load__():
+    global __color__
+    import os
+    import pickle
+    path = os.path.abspath(__file__)
+    path = os.path.dirname(path)
+    file = open(os.path.join(path, "color_renderer.pkl"), "rb")
+    __return__ = pickle.load(file)
+    file.close()
+    __color__ = __return__
+    return __return__
+    
+class __black__:
     def __str__(self):
         return "\033[90m"
     def __add__(self, other: str):
@@ -32,7 +41,7 @@ class __black:
         return other + "\033[90m"
     normal = "\033[30m"
     dark = "\033[2;30m"
-class __red:
+class __red__:
     def __str__(self):
         return "\033[91m"
     def __add__(self, other: str):
@@ -41,7 +50,7 @@ class __red:
         return other + "\033[91m"
     normal = "\033[31m"
     dark = "\033[2;31m"
-class __green:
+class __green__:
     def __str__(self):
         return "\033[92m"
     def __add__(self, other: str):
@@ -50,7 +59,7 @@ class __green:
         return other + "\033[92m"
     normal = "\033[32m"
     dark = "\033[2;32m"
-class __yellow:
+class __yellow__:
     def __str__(self):
         return "\033[93m"
     def __add__(self, other: str):
@@ -59,7 +68,7 @@ class __yellow:
         return other + "\033[93m"
     normal = "\033[33m"
     dark = "\033[2;33m"
-class __blue:
+class __blue__:
     def __str__(self):
         return "\033[94m"
     def __add__(self, other: str):
@@ -68,7 +77,7 @@ class __blue:
         return other + "\033[94m"
     normal = "\033[34m"
     dark = "\033[2;34m"
-class __purple:
+class __purple__:
     def __str__(self):
         return "\033[95m"
     def __add__(self, other: str):
@@ -77,7 +86,7 @@ class __purple:
         return other + "\033[95m"
     normal = "\033[35m"
     dark = "\033[2;35m"
-class __cyan:
+class __cyan__:
     def __str__(self):
         return "\033[96m"
     def __add__(self, other: str):
@@ -86,7 +95,7 @@ class __cyan:
         return other + "\033[96m"
     normal = "\033[36m"
     dark = "\033[2;36m"
-class __white:
+class __white__:
     def __str__(self):
         return "\033[97m"
     def __add__(self, other: str):
@@ -97,15 +106,15 @@ class __white:
     dark = "\033[2;37m"
 
 off = "\033[0m"
-black = __black()
-red = __red()
-green = __green()
-yellow = __yellow()
-blue = __blue()
-purple = __purple()
-cyan = __cyan()
-white = __white()
-def toning(R: int = 0, G: int = 0, B: int = 0):
+black = __black__()
+red = __red__()
+green = __green__()
+yellow = __yellow__()
+blue = __blue__()
+purple = __purple__()
+cyan = __cyan__()
+white = __white__()
+def toning(R: int = 255, G: int = 255, B: int = 255):
     return f"\033[38;2;{R};{G};{B}m"
 
 
